==> jc-1.4.0.tar.gz: java/awt/dnd/DropTargetAdapter.h <==
// public abstract class java.awt.dnd.DropTargetAdapter

// class file dependencies
// @dep_class 8f4e46c268d5d427 java_awt_dnd_DropTargetAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_dnd_DropTargetAdapter_H_
#define _JC_java_awt_dnd_DropTargetAdapter_H_

// Forward structure declarations
struct _jc_java_awt_dnd_DropTargetDragEvent$object;
struct _jc_java_awt_dnd_DropTargetEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DropTargetAdapter$sub_refs	_jc_java_awt_dnd_DropTargetAdapter$sub_refs;
typedef struct _jc_java_awt_dnd_DropTargetAdapter$sub_nonrefs	_jc_java_awt_dnd_DropTargetAdapter$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetAdapter$refs	_jc_java_awt_dnd_DropTargetAdapter$refs;
typedef struct _jc_java_awt_dnd_DropTargetAdapter$nonrefs	_jc_java_awt_dnd_DropTargetAdapter$nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetAdapter$object	_jc_java_awt_dnd_DropTargetAdapter$object;

typedef const struct _jc_java_awt_dnd_DropTargetAdapter$vmethods	_jc_java_awt_dnd_DropTargetAdapter$vmethods;
typedef const struct _jc_java_awt_dnd_DropTargetAdapter$vtable	_jc_java_awt_dnd_DropTargetAdapter$vtable;
typedef const struct _jc_java_awt_dnd_DropTargetAdapter$vtype	_jc_java_awt_dnd_DropTargetAdapter$vtype;

// Constructors
extern void _jc_java_awt_dnd_DropTargetAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *);

// Virtual methods
extern void _jc_java_awt_dnd_DropTargetAdapter$method$dragEnter$f69ae040e9dab2b3(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
extern void _jc_java_awt_dnd_DropTargetAdapter$method$dragExit$55999cc61b1f41c0(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetEvent$object *);
extern void _jc_java_awt_dnd_DropTargetAdapter$method$dragOver$bc0c11d9ac763ff0(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
extern void _jc_java_awt_dnd_DropTargetAdapter$method$dropActionChanged$6c6c04cebae25c73(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DropTargetAdapter$method_info$dragEnter$f69ae040e9dab2b3;
extern _jc_method _jc_java_awt_dnd_DropTargetAdapter$method_info$dragExit$55999cc61b1f41c0;
extern _jc_method _jc_java_awt_dnd_DropTargetAdapter$method_info$dragOver$bc0c11d9ac763ff0;
extern _jc_method _jc_java_awt_dnd_DropTargetAdapter$method_info$dropActionChanged$6c6c04cebae25c73;

// Virtual methods structure
struct _jc_java_awt_dnd_DropTargetAdapter$vmethods {
	void	(*dragEnter$f69ae040e9dab2b3)(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
	void	(*dragExit$55999cc61b1f41c0)(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetEvent$object *);
	void	(*dragOver$bc0c11d9ac763ff0)(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
	void	(*dropActionChanged$6c6c04cebae25c73)(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
};

// Vtable
struct _jc_java_awt_dnd_DropTargetAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_dnd_DropTargetAdapter$vmethods	java_awt_dnd_DropTargetAdapter;
};

// Vtype
struct _jc_java_awt_dnd_DropTargetAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DropTargetAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetAdapter$refs {
    _jc_java_awt_dnd_DropTargetAdapter$sub_refs	java_awt_dnd_DropTargetAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_dnd_DropTargetAdapter$sub_nonrefs	java_awt_dnd_DropTargetAdapter;
};

// Object instance structure
struct _jc_java_awt_dnd_DropTargetAdapter$object {
	_jc_java_awt_dnd_DropTargetAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DropTargetAdapter$vtype	*vtype;
	_jc_java_awt_dnd_DropTargetAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DropTargetAdapter$vtype _jc_java_awt_dnd_DropTargetAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DropTargetAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DropTargetAdapter$class_object;

#endif	/* _JC_java_awt_dnd_DropTargetAdapter_H_ */

==> jc-1.4.6.tar.gz: java/awt/dnd/DropTargetAdapter.h <==
// public abstract class java.awt.dnd.DropTargetAdapter

// class file dependencies
// @dep_class 8f4e46c268d5d427 java_awt_dnd_DropTargetAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_dnd_DropTargetAdapter_H_
#define _JC_java_awt_dnd_DropTargetAdapter_H_

// Forward structure declarations
struct _jc_java_awt_dnd_DropTargetDragEvent$object;
struct _jc_java_awt_dnd_DropTargetEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DropTargetAdapter$sub_refs	_jc_java_awt_dnd_DropTargetAdapter$sub_refs;
typedef struct _jc_java_awt_dnd_DropTargetAdapter$sub_nonrefs	_jc_java_awt_dnd_DropTargetAdapter$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetAdapter$refs	_jc_java_awt_dnd_DropTargetAdapter$refs;
typedef struct _jc_java_awt_dnd_DropTargetAdapter$nonrefs	_jc_java_awt_dnd_DropTargetAdapter$nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetAdapter$object	_jc_java_awt_dnd_DropTargetAdapter$object;

typedef const struct _jc_java_awt_dnd_DropTargetAdapter$vmethods	_jc_java_awt_dnd_DropTargetAdapter$vmethods;
typedef const struct _jc_java_awt_dnd_DropTargetAdapter$vtable	_jc_java_awt_dnd_DropTargetAdapter$vtable;
typedef const struct _jc_java_awt_dnd_DropTargetAdapter$vtype	_jc_java_awt_dnd_DropTargetAdapter$vtype;

// Constructors
extern void _jc_java_awt_dnd_DropTargetAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_dnd_DropTargetAdapter$method$dragEnter$f69ae040e9dab2b3(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_dnd_DropTargetAdapter$method$dragExit$55999cc61b1f41c0(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_dnd_DropTargetAdapter$method$dragOver$bc0c11d9ac763ff0(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_dnd_DropTargetAdapter$method$dropActionChanged$6c6c04cebae25c73(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DropTargetAdapter$method_info$dragEnter$f69ae040e9dab2b3;
extern _jc_method _jc_java_awt_dnd_DropTargetAdapter$method_info$dragExit$55999cc61b1f41c0;
extern _jc_method _jc_java_awt_dnd_DropTargetAdapter$method_info$dragOver$bc0c11d9ac763ff0;
extern _jc_method _jc_java_awt_dnd_DropTargetAdapter$method_info$dropActionChanged$6c6c04cebae25c73;

// Virtual methods structure
struct _jc_java_awt_dnd_DropTargetAdapter$vmethods {
	void	(*dragEnter$f69ae040e9dab2b3)(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
	void	(*dragExit$55999cc61b1f41c0)(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetEvent$object *) _JC_JCNI_ATTR;
	void	(*dragOver$bc0c11d9ac763ff0)(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
	void	(*dropActionChanged$6c6c04cebae25c73)(_jc_env *, struct _jc_java_awt_dnd_DropTargetAdapter$object *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_dnd_DropTargetAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_dnd_DropTargetAdapter$vmethods	java_awt_dnd_DropTargetAdapter;
};

// Vtype
struct _jc_java_awt_dnd_DropTargetAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DropTargetAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetAdapter$refs {
    _jc_java_awt_dnd_DropTargetAdapter$sub_refs	java_awt_dnd_DropTargetAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_dnd_DropTargetAdapter$sub_nonrefs	java_awt_dnd_DropTargetAdapter;
};

// Object instance structure
struct _jc_java_awt_dnd_DropTargetAdapter$object {
	_jc_java_awt_dnd_DropTargetAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DropTargetAdapter$vtype	*vtype;
	_jc_java_awt_dnd_DropTargetAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DropTargetAdapter$vtype _jc_java_awt_dnd_DropTargetAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DropTargetAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DropTargetAdapter$class_object;

#endif	/* _JC_java_awt_dnd_DropTargetAdapter_H_ */
